@@ -14,17 +14,18 @@ class Instances(CTkFrame):
 
         self.grid_columnconfigure(0, weight=1)
 
-        self.app_name = CTkLabel(
-            master=self,
-            height=100,
-            fg_color=("white", "gray38"),  # <- custom tuple-color
-            text_font=("Roboto Medium", -20),  # font name and size in px
+        self.title_frame = CTkFrame(master=self, fg_color="gray38")
+        self.title_frame.grid(row=0, column=0, pady=20, padx=20, sticky="nswe")
+
+        self.view_name = CTkLabel(
+            master=self.title_frame,
+            text_font=("Roboto Medium", 30),
             text="Instances",
         )
-        self.app_name.grid(row=0, column=0, pady=20, padx=20, sticky="nswe")
+        self.view_name.grid(row=0, column=0, pady=20, padx=20, sticky="nswe")
 
         self.instances_list = CTkFrame(master=self)
-        self.instances_list.grid(row=1, column=0, pady=10, padx=10, sticky="nswe")
+        self.instances_list.grid(row=1, column=0, pady=20, padx=20, sticky="nswe")
         self.instances_list.grid_columnconfigure(1, weight=1)
 
         # empty row as spacing
